@@ -24,22 +24,24 @@ from qtpy.QtGui import (QBrush, QColor, QIcon, QPainter, QPainterPath, QPen,
                         QPixmap, QRegion)
 from qtpy.QtWidgets import (QAction, QApplication, QComboBox, QDialog,
                             QGraphicsOpacityEffect, QHBoxLayout, QLabel,
-                            QLayout, QMainWindow, QMenu, QPushButton,
-                            QSpacerItem, QToolButton, QVBoxLayout, QWidget)
+                            QLayout, QMainWindow, QMenu, QMessageBox,
+                            QPushButton, QSpacerItem, QToolButton, QVBoxLayout,
+                            QWidget)
 
 # Local imports
-from spyder.config.base import _, get_image_path
-from spyder.config.gui import is_dark_interface
+from spyder import __docs_url__
+from spyder.api.panel import Panel
+from spyder.config.base import _
+from spyder.utils.image_path_manager import get_image_path
 from spyder.py3compat import to_binary_string
 from spyder.utils.qthelpers import add_actions, create_action
-from spyder.utils import icon_manager as ima
+from spyder.utils.icon_manager import ima
+from spyder.utils.palette import QStylePalette, SpyderPalette
 
 
-if is_dark_interface():
-    MAIN_TOP_COLOR = MAIN_BG_COLOR = QColor.fromRgb(25, 35, 45)
-else:
-    MAIN_TOP_COLOR = QColor.fromRgb(230, 230, 230)
-    MAIN_BG_COLOR = QColor.fromRgb(255, 255, 255)
+MAIN_TOP_COLOR = MAIN_BG_COLOR = QColor(QStylePalette.COLOR_BACKGROUND_1)
+
+MAC = sys.platform == 'darwin'
 
 # FIXME: Known issues
 # How to handle if an specific dockwidget does not exists/load, like ipython
@@ -50,12 +52,18 @@ class SpyderWidgets(object):
     # Panes
     ipython_console = 'ipyconsole'
     editor = 'editor'
-    editor_line_number_area = 'editor.get_current_editor().linenumberarea'
+    panel = Panel.Position.LEFT
+    editor_line_number_area = (
+        f'editor.get_current_editor().panels._panels[{panel}].values()')
     editor_scroll_flag_area = 'editor.get_current_editor().scrollflagarea'
     file_explorer = 'explorer'
     help_plugin = 'help'
     variable_explorer = 'variableexplorer'
     history_log = "historylog"
+    plots_plugin = "plots"
+    find_plugin = "findinfiles"
+    profiler = "Profiler"
+    code_analysis = "Pylint"
 
     # Toolbars
     toolbars = ''
@@ -94,6 +102,11 @@ def get_tour(index):
     """
     sw = SpyderWidgets
     qtconsole_link = "https://qtconsole.readthedocs.io/en/stable/index.html"
+    button_text = ""
+    if sys.platform != "darwin":
+        button_text = ("Please click on the button below to run some simple "
+                       "code in this console. This will be useful to show "
+                       "you other important features.")
 
     # This test should serve as example of keys to use in the tour frame dics
     test = [{'title': "Welcome to Spyder introduction tour",
@@ -101,7 +114,7 @@ def get_tour(index):
                          environment. This tip panel supports rich text. <br>\
                          <br> it also supports image insertion to the right so\
                          far",
-             'image': 'tour-spyder-logo.png'},
+             'image': 'spyder_about'},
 
             {'title': "Widget display",
              'content': ("This show how a widget is displayed. The tip panel "
@@ -130,58 +143,64 @@ def get_tour(index):
              'interact': False},
             ]
 
-    intro = [{'title': _("Welcome to the Introduction tour"),
+    intro = [{'title': _("Welcome to the introduction tour!"),
               'content': _("<b>Spyder</b> is a powerful Interactive "
                            "Development Environment (or IDE) for the Python "
                            "programming language.<br><br>"
-                           "Here we are going to guide you through its most "
+                           "Here, we are going to guide you through its most "
                            "important features.<br><br>"
                            "Please use the arrow keys or click on the buttons "
                            "below to move along the tour."),
-              'image': 'tour-spyder-logo.png'},
+              'image': 'spyder_about'},
 
-             {'title': _("The Editor"),
-              'content': _("This is the pane where you write Python code before "
-                           "evaluating it. You can get automatic suggestions "
-                           "and completions while writing, by pressing the "
-                           "<b>Tab</b> key next to a given text.<br><br>"
-                           "The Editor comes "
-                           "with a line number area (highlighted here in red), "
-                           "where Spyder shows warnings and syntax errors. They "
-                           "can help you to detect potential problems before "
-                           "running the code.<br><br>"
+             {'title': _("Editor"),
+              'content': _("This is where you write Python code before "
+                           "evaluating it. You can get automatic "
+                           "completions while typing, along with calltips "
+                           "when calling a function and help when hovering "
+                           "over an object."
+                           "<br><br>The Editor comes "
+                           "with a line number area (highlighted here in red) "
+                           "where Spyder shows warnings and syntax errors. "
+                           "They can help you to detect potential problems "
+                           "before running your code.<br><br>"
                            "You can also set debug breakpoints in the line "
-                           "number area, by doing a double click next to "
-                           "a non-empty line."),
+                           "number area by clicking next to "
+
+                           "any non-empty line."),
               'widgets': [sw.editor],
               'decoration': [sw.editor_line_number_area]},
 
-             {'title': _("The IPython console"),
-              'content': _("This is one of panes where you can run or "
-                           "execute the code you wrote on the Editor. To do it "
-                           "you need to press the <b>F5</b> key.<br><br>"
-                           "This console comes with several "
+             {'title': _("IPython Console"),
+              'content': _("This is where you can run Python code, either "
+                           "from the Editor or interactively. To run the "
+                           "current file, press <b>F5</b> by default, "
+                           "or press <b>F9</b> to execute the current "
+                           "line or selection.<br><br>"
+                           "The IPython Console comes with many "
                            "useful features that greatly improve your "
-                           "programming workflow (like syntax highlighting and "
-                           "inline plots). If you want to know more about them, "
-                           "please follow this <a href=\"{0}\">link</a>.<br><br>"
-                           "Please click on the button below to run some simple "
-                           "code in this console. This will be useful to show "
-                           "you other important features.").format(
-                           qtconsole_link),
+                           "programming workflow, like syntax highlighting, "
+                           "autocompletion, plotting and 'magic' commands. "
+                           "To learn more, check out the "
+                           "<a href=\"{0}\">documentation</a>."
+                           "<br><br>{1}").format(qtconsole_link, button_text),
               'widgets': [sw.ipython_console],
-              'run': ["li = list(range(100))", "d = {'a': 1, 'b': 2}"]
+              'run': [
+                  "test_list_tour = [1, 2, 3, 4, 5]",
+                  "test_dict_tour = {'a': 1, 'b': 2}",
+                  ]
               },
 
-             {'title': _("The Variable Explorer"),
+             {'title': _("Variable Explorer"),
               'content': _("In this pane you can view and edit the variables "
                            "generated during the execution of a program, or "
-                           "those entered directly in one of Spyder "
-                           "consoles.<br><br>"
-                           "As you can see, the Variable Explorer is showing "
-                           "the variables generated during the last step of "
-                           "this tour. By doing a double-click on any "
-                           "of them, a new window will be opened, where you "
+                           "those entered directly in the "
+                           "IPython Console.<br><br>"
+                           "If you ran the code in the previous step, "
+                           "the Variable Explorer will show "
+                           "the list and dictionary objects it generated. "
+                           "By double-clicking any variable, "
+                           "a new window will be opened where you "
                            "can inspect and modify their contents."),
               'widgets': [sw.variable_explorer],
               'interact': True},
@@ -189,30 +208,74 @@ def get_tour(index):
              {'title': _("Help"),
               'content': _("This pane displays documentation of the "
                            "functions, classes, methods or modules you are "
-                           "currently using in the Editor or the Consoles.<br><br>"
-                           "To use it, you need to press <b>Ctrl+I</b> in "
-                           "front of an object. If that object has some "
-                           "documentation associated with it, it will be "
-                           "displayed here."),
+                           "currently using in the Editor or the "
+                           "IPython Console."
+                           "<br><br>To use it, press <b>Ctrl+I</b> "
+                           "(<b>Cmd-I</b> on macOS) with the text cursor "
+                           "in or next to the object you want help on."),
               'widgets': [sw.help_plugin],
               'interact': True},
 
-             {'title': _("The File Explorer"),
-              'content': _("This pane lets you navigate through the directories "
-                           "and files present in your computer.<br><br>"
-                           "You can also open any of these files with its "
-                           "corresponding application, by doing a double "
-                           "click on it.<br><br>"
-                           "There is one exception to this rule: plain-text "
-                           "files will always be opened in the Spyder Editor."),
+             {'title': _("Plots"),
+              'content': _("This pane shows the figures and images created "
+                           "during your code execution. It allows you to browse, "
+                           "zoom, copy, and save the generated plots."),
+              'widgets': [sw.plots_plugin],
+              'interact': True},
+
+             {'title': _("Files"),
+              'content': _("This pane lets you browse the files and "
+                           "directories on your computer.<br><br>"
+                           "You can open any file in its "
+                           "corresponding application by double-clicking it, "
+                           "and supported file types will be opened right "
+                           "inside of Spyder.<br><br>"
+                           "The Files pane also allows you to copy one or "
+                           "many absolute or relative paths, automatically "
+                           "formatted as Python strings or lists, and perform "
+                           "a variety of other file operations."),
               'widgets': [sw.file_explorer],
               'interact': True},
 
-             {'title': _("The History Log"),
-              'content': _("This pane records all commands introduced in "
-                           "the Python and IPython consoles."),
+             {'title': _("History Log"),
+              'content': _("This pane records all the commands and code run "
+                           "in any IPython console, allowing you to easily "
+                           "retrace your steps for reproducible research."),
+
               'widgets': [sw.history_log],
               'interact': True},
+
+             {'title': _("Find"),
+              'content': _("The Find pane allows you to search for text in a "
+                           "given directory and navigate through all the found "
+                           "occurrences."),
+              'widgets': [sw.find_plugin],
+              'interact': True},
+
+             {'title': _("Profiler"),
+              'content': _("The Profiler helps you optimize your code by determining "
+                           "the run time and number of calls for every function and "
+                           "method used in a file. It also allows you to save and "
+                           "compare your results between runs."),
+              'widgets': [sw.profiler],
+              'interact': True},
+
+             {'title': _("Code Analysis"),
+              'content': _("The Code Analysis helps you improve the quality of "
+                           "your programs by detecting style issues, bad practices "
+                           "and potential bugs."),
+              'widgets': [sw.code_analysis],
+              'interact': True},
+
+             {'title': _("The end"),
+              'content': _('You have reached the end of our tour and are '
+                           'ready to start using Spyder! For more '
+                           'information, check out our '
+                           '<a href="{}">documentation</a>.'
+                           '<br><br>').format(__docs_url__),
+              'image': 'spyder_about'
+              },
+
              ]
 
 #                   ['The run toolbar',
@@ -259,7 +322,7 @@ def get_tour(index):
     feat30 = [{'title': "New features in Spyder 3.0",
                'content': _("<b>Spyder</b> is an interactive development "
                             "environment based on bla"),
-               'image': 'spyder.png'},
+               'image': 'spyder_about'},
 
               {'title': _("Welcome to Spyder introduction tour"),
                'content': _("Spyder is an interactive development environment "
@@ -395,9 +458,12 @@ class FadingCanvas(FadingDialog):
         self.parent = parent
         self.tour = tour
 
-        self.color = color              # Canvas color
-        self.color_decoration = Qt.red  # Decoration color
-        self.stroke_decoration = 2      # width in pixels for decoration
+        # Canvas color
+        self.color = color
+        # Decoration color
+        self.color_decoration = QColor(SpyderPalette.COLOR_ERROR_2)
+        # Width in pixels for decoration
+        self.stroke_decoration = 2
 
         self.region_mask = None
         self.region_subtract = None
@@ -437,7 +503,6 @@ class FadingCanvas(FadingDialog):
         self.region_mask = QRegion(0, 0, w, h)
 
         self.path_full.addRect(0, 0, w, h)
-
         # Add the path
         if self.widgets is not None:
             for widget in self.widgets:
@@ -462,16 +527,26 @@ class FadingCanvas(FadingDialog):
             self.path_current = self.path_full.subtracted(self.path_subtract)
         else:
             self.path_current = self.path_full
-
         if self.decoration is not None:
-            for widget in self.decoration:
+            for widgets in self.decoration:
+                if isinstance(widgets, QWidget):
+                    widgets = [widgets]
+                geoms = []
+                for widget in widgets:
+                    widget.raise_()
+                    widget.show()
+                    geo = widget.frameGeometry()
+                    width, height = geo.width(), geo.height()
+                    point = widget.mapTo(self.parent, QPoint(0, 0))
+                    x, y = point.x(), point.y()
+                    geoms.append((x, y, width, height))
+                x = min([geom[0] for geom in geoms])
+                y = min([geom[1] for geom in geoms])
+                width = max([
+                    geom[0] + geom[2] for geom in geoms]) - x
+                height = max([
+                    geom[1] + geom[3] for geom in geoms]) - y
                 temp_path = QPainterPath()
-                widget.raise_()
-                widget.show()
-                geo = widget.frameGeometry()
-                width, height = geo.width(), geo.height()
-                point = widget.mapTo(self.parent, QPoint(0, 0))
-                x, y = point.x(), point.y()
                 temp_path.addRect(QRectF(x, y, width, height))
 
                 temp_region_1 = QRegion(x-1, y-1, width+2, height+2)
@@ -577,6 +652,7 @@ class FadingTipBox(FadingDialog):
         self.label_current = QLabel()
         self.label_content = QLabel()
 
+        self.label_content.setOpenExternalLinks(True)
         self.label_content.setMinimumWidth(self.fixed_width)
         self.label_content.setMaximumWidth(self.fixed_width)
 
@@ -590,7 +666,7 @@ class FadingTipBox(FadingDialog):
                         self.button_previous, self.button_end,
                         self.button_home, self.button_current]
 
-        arrow = get_image_path('hide.png')
+        arrow = get_image_path('hide')
 
         self.color_top = color_top
         self.color_back = color_back
@@ -696,6 +772,7 @@ class FadingTipBox(FadingDialog):
         elif self.button_disable == 'next':
             self.button_next.setDisabled(True)
             self.button_end.setDisabled(True)
+        self.button_run.setDisabled(sys.platform == "darwin")
 
     def set_data(self, title, content, current, image, run, frames=None,
                  step=None):
@@ -725,8 +802,9 @@ class FadingTipBox(FadingDialog):
         if run is None:
             self.button_run.setVisible(False)
         else:
-            self.button_run.setDisabled(False)
             self.button_run.setVisible(True)
+            if sys.platform == "darwin":
+                self.button_run.setToolTip("Not available on macOS")
 
         # Refresh layout
         self.layout().activate()
@@ -865,6 +943,7 @@ class AnimatedTour(QWidget):
         self.tips = None
         self.frames = None
         self.spy_window = None
+        self.initial_fullscreen_state = None
 
         self.widgets = None
         self.dockwidgets = None
@@ -913,8 +992,8 @@ class AnimatedTour(QWidget):
     def _resized(self, event):
         """ """
         if self.is_running:
-            size = event.size()
-            self.canvas.setFixedSize(size)
+            geom = self.parent.geometry()
+            self.canvas.setFixedSize(geom.width(), geom.height())
             self.canvas.update_canvas()
 
             if self.is_tour_set:
@@ -923,8 +1002,8 @@ class AnimatedTour(QWidget):
     def _moved(self, event):
         """ """
         if self.is_running:
-            pos = event.pos()
-            self.canvas.move(QPoint(pos.x(), pos.y()))
+            geom = self.parent.geometry()
+            self.canvas.move(geom.x(), geom.y())
 
             if self.is_tour_set:
                 self._set_data()
@@ -936,7 +1015,7 @@ class AnimatedTour(QWidget):
 
     def _clear_canvas(self):
         """ """
-        # TODO: Add option to also make it white... might be usefull?
+        # TODO: Add option to also make it white... might be useful?
         # Make canvas black before transitions
         self.canvas.update_widgets(None)
         self.canvas.update_decoration(None)
@@ -982,13 +1061,25 @@ class AnimatedTour(QWidget):
         dockwidgets = []
 
         for name in names:
-            base = name.split('.')[0]
-            temp = getattr(spy_window, base)
-
-            # Check if it is the current editor
-            if 'get_current_editor()' in name:
-                temp = temp.get_current_editor()
-                temp = getattr(temp, name.split('.')[-1])
+            try:
+                base = name.split('.')[0]
+                try:
+                    temp = getattr(spy_window, name)
+                except AttributeError:
+                    for item in spy_window.thirdparty_plugins:
+                        if type(item).__name__ == name:
+                            temp = item
+                            break
+                    else:
+                        temp = None
+                    # Check if it is the current editor
+                    if 'get_current_editor()' in name:
+                        temp = temp.get_current_editor()
+                        temp = getattr(temp, name.split('.')[-1])
+                    if temp is None:
+                        raise
+            except AttributeError:
+                temp = eval(f"spy_window.{name}")
 
             widgets.append(temp)
 
@@ -1048,7 +1139,7 @@ class AnimatedTour(QWidget):
             self._set_modal(True, [self.tips])
 
         if 'run' in frame:
-            # Asume that the frist widget is the console
+            # Assume that the first widget is the console
             run = frame['run']
             self.run = run
 
@@ -1074,6 +1165,7 @@ class AnimatedTour(QWidget):
         self.y_main = y
 
         delta = 20
+        offset = 10
 
         # Here is the tricky part to define the best position for the
         # tip widget
@@ -1085,23 +1177,20 @@ class AnimatedTour(QWidget):
                 point = dockwidgets[0].mapToGlobal(QPoint(0, 0))
                 x_glob, y_glob = point.x(), point.y()
 
-                # Check if is too tall and put to the side
-                y_fac = (height / self.height_main) * 100
-
-                if y_fac > 60:  # FIXME:
-                    if x < self.tips.width():
-                        x = x_glob + width + delta
-                        y = y_glob + height/2 - self.tips.height()/2
-                    else:
-                        x = x_glob - self.tips.width() - delta
-                        y = y_glob + height/2 - self.tips.height()/2
+                # Put tip to the opposite side of the pane
+                if x < self.tips.width():
+                    x = x_glob + width + delta
+                    y = y_glob + height/2 - self.tips.height()/2
                 else:
-                    if y < self.tips.height():
-                        x = x_glob + width/2 - self.tips.width()/2
-                        y = y_glob + height + delta
-                    else:
-                        x = x_glob + width/2 - self.tips.width()/2
-                        y = y_glob - delta - self.tips.height()
+                    x = x_glob - self.tips.width() - delta
+                    y = y_glob + height/2 - self.tips.height()/2
+
+                if (y + self.tips.height()) > (self.y_main + self.height_main):
+                    y = (
+                        y
+                        - (y + self.tips.height() - (self.y_main + self.height_main))
+                        - offset
+                    )
         else:
             # Center on parent
             x = self.x_main + self.width_main/2 - self.tips.width()/2
@@ -1162,8 +1251,36 @@ class AnimatedTour(QWidget):
 
         self.is_tour_set = True
 
+    def _handle_fullscreen(self):
+        if (self.spy_window.isFullScreen() or
+                self.spy_window.layouts._fullscreen_flag):
+            if sys.platform == 'darwin':
+                self.spy_window.setUpdatesEnabled(True)
+                msg_title = _("Request")
+                msg = _("To run the tour, please press the green button on "
+                        "the left of the Spyder window's title bar to take "
+                        "it out of fullscreen mode.")
+                QMessageBox.information(self, msg_title, msg,
+                                        QMessageBox.Ok)
+                return True
+            if self.spy_window.layouts._fullscreen_flag:
+                self.spy_window.layouts.toggle_fullscreen()
+            else:
+                self.spy_window.setWindowState(
+                    self.spy_window.windowState()
+                    & (~ Qt.WindowFullScreen))
+        return False
+
     def start_tour(self):
         """ """
+        self.spy_window.setUpdatesEnabled(False)
+        if self._handle_fullscreen():
+            return
+        self.spy_window.layouts.save_current_window_settings(
+            'layout_current_temp/',
+            section="quick_layouts",
+        )
+        self.spy_window.layouts.quick_layout_switch('default')
         geo = self.parent.geometry()
         x, y, width, height = geo.x(), geo.y(), geo.width(), geo.height()
 #        self.parent_x = x
@@ -1178,6 +1295,7 @@ class AnimatedTour(QWidget):
         # Adjust the canvas size to match the main window size
         self.canvas.setFixedSize(width, height)
         self.canvas.move(QPoint(x, y))
+        self.spy_window.setUpdatesEnabled(True)
         self.canvas.fade_in(self._move_step)
         self._clear_canvas()
 
@@ -1186,6 +1304,7 @@ class AnimatedTour(QWidget):
     def close_tour(self):
         """ """
         self.tips.fade_out(self._close_canvas)
+        self.spy_window.setUpdatesEnabled(False)
         self.canvas.set_interaction(False)
         self._set_modal(True, [self.tips])
         self.canvas.hide()
@@ -1199,6 +1318,8 @@ class AnimatedTour(QWidget):
             pass
 
         self.is_running = False
+        self.spy_window.layouts.quick_layout_switch('current_temp')
+        self.spy_window.setUpdatesEnabled(True)
 
     def hide_tips(self):
         """Hide tips dialog when the main window loses focus."""
@@ -1239,9 +1360,16 @@ class AnimatedTour(QWidget):
 
     def lost_focus(self):
         """Confirm if the tour loses focus and hides the tips."""
-        if (self.is_running and not self.any_has_focus() and
-            not self.setting_data and not self.hidden):
-            self.hide_tips()
+        if (self.is_running and
+                not self.setting_data and not self.hidden):
+            if sys.platform == 'darwin':
+                if not self.tour_has_focus():
+                    self.hide_tips()
+                    if not self.any_has_focus():
+                        self.close_tour()
+            else:
+                if not self.any_has_focus():
+                    self.hide_tips()
 
     def gain_focus(self):
         """Confirm if the tour regains focus and unhides the tips."""
@@ -1250,11 +1378,169 @@ class AnimatedTour(QWidget):
             self.unhide_tips()
 
     def any_has_focus(self):
-        """Returns if tour or any of its components has focus."""
+        """Returns True if tour or main window has focus."""
         f = (self.hasFocus() or self.parent.hasFocus() or
-             self.tips.hasFocus() or self.canvas.hasFocus())
+             self.tour_has_focus() or self.isActiveWindow())
         return f
 
+    def tour_has_focus(self):
+        """Returns true if tour or any of its components has focus."""
+        f = (self.tips.hasFocus() or self.canvas.hasFocus() or
+             self.tips.isActiveWindow())
+        return f
+
+
+class OpenTourDialog(QDialog):
+    """Initial Widget with tour"""
+
+    ICON_SCALE_FACTOR = 0.7 if MAC else 0.75
+    TITLE_FONT_SIZE = '19pt' if MAC else '16pt'
+    CONTENT_FONT_SIZE = '15pt' if MAC else '12pt'
+    BUTTONS_FONT_SIZE = '15pt' if MAC else '13pt'
+    BUTTONS_PADDING = '6px' if MAC else '4px 10px'
+
+    def __init__(self, parent, tour_function):
+        super().__init__(parent)
+        self.setWindowFlags(
+            self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.tour_function = tour_function
+
+        # Image
+        images_layout = QHBoxLayout()
+        icon_filename = 'tour-spyder-logo'
+        image_path = get_image_path(icon_filename)
+        image = QPixmap(image_path)
+        image_label = QLabel()
+        image_height = image.height() * self.ICON_SCALE_FACTOR
+        image_width = image.width() * self.ICON_SCALE_FACTOR
+        image = image.scaled(image_width, image_height, Qt.KeepAspectRatio,
+                             Qt.SmoothTransformation)
+        image_label.setPixmap(image)
+
+        images_layout.addStretch()
+        images_layout.addWidget(image_label)
+        images_layout.addStretch()
+        if MAC:
+            images_layout.setContentsMargins(0, -5, 20, 0)
+        else:
+            images_layout.setContentsMargins(0, -8, 35, 0)
+
+        # Label
+        tour_label_title = QLabel(_("Welcome to Spyder!"))
+        tour_label_title.setStyleSheet(f"font-size: {self.TITLE_FONT_SIZE}")
+        tour_label_title.setWordWrap(True)
+        tour_label = QLabel(
+            _("Check out our interactive tour to "
+              "explore some of Spyder's panes and features."))
+        tour_label.setStyleSheet(f"font-size: {self.CONTENT_FONT_SIZE}")
+        tour_label.setWordWrap(True)
+        tour_label.setFixedWidth(340)
+
+        # Buttons
+        buttons_layout = QHBoxLayout()
+        dialog_tour_color = QStylePalette.COLOR_BACKGROUND_2
+        start_tour_color = QStylePalette.COLOR_ACCENT_2
+        start_tour_hover = QStylePalette.COLOR_ACCENT_3
+        start_tour_pressed = QStylePalette.COLOR_ACCENT_4
+        dismiss_tour_color = QStylePalette.COLOR_BACKGROUND_4
+        dismiss_tour_hover = QStylePalette.COLOR_BACKGROUND_5
+        dismiss_tour_pressed = QStylePalette.COLOR_BACKGROUND_6
+        font_color = QStylePalette.COLOR_TEXT_1
+        self.launch_tour_button = QPushButton(_('Start tour'))
+        self.launch_tour_button.setStyleSheet((
+          "QPushButton {{ "
+          "background-color: {background_color};"
+          "border-color: {border_color};"
+          "font-size: {font_size};"
+          "color: {font_color};"
+          "padding: {padding}}}"
+          "QPushButton:hover:!pressed {{ "
+          "background-color: {color_hover}}}"
+          "QPushButton:pressed {{ "
+          "background-color: {color_pressed}}}"
+        ).format(background_color=start_tour_color,
+                 border_color=start_tour_color,
+                 font_size=self.BUTTONS_FONT_SIZE,
+                 font_color=font_color,
+                 padding=self.BUTTONS_PADDING,
+                 color_hover=start_tour_hover,
+                 color_pressed=start_tour_pressed))
+        self.launch_tour_button.setAutoDefault(False)
+        self.dismiss_button = QPushButton(_('Dismiss'))
+        self.dismiss_button.setStyleSheet((
+          "QPushButton {{ "
+          "background-color: {background_color};"
+          "border-color: {border_color};"
+          "font-size: {font_size};"
+          "color: {font_color};"
+          "padding: {padding}}}"
+          "QPushButton:hover:!pressed {{ "
+          "background-color: {color_hover}}}"
+          "QPushButton:pressed {{ "
+          "background-color: {color_pressed}}}"
+        ).format(background_color=dismiss_tour_color,
+                 border_color=dismiss_tour_color,
+                 font_size=self.BUTTONS_FONT_SIZE,
+                 font_color=font_color,
+                 padding=self.BUTTONS_PADDING,
+                 color_hover=dismiss_tour_hover,
+                 color_pressed=dismiss_tour_pressed))
+        self.dismiss_button.setAutoDefault(False)
+
+        buttons_layout.addStretch()
+        buttons_layout.addWidget(self.launch_tour_button)
+        if not MAC:
+            buttons_layout.addSpacing(10)
+        buttons_layout.addWidget(self.dismiss_button)
+
+        layout = QHBoxLayout()
+        layout.addLayout(images_layout)
+
+        label_layout = QVBoxLayout()
+        label_layout.addWidget(tour_label_title)
+        if not MAC:
+            label_layout.addSpacing(3)
+            label_layout.addWidget(tour_label)
+        else:
+            label_layout.addWidget(tour_label)
+            label_layout.addSpacing(10)
+
+        vertical_layout = QVBoxLayout()
+        if not MAC:
+            vertical_layout.addStretch()
+            vertical_layout.addLayout(label_layout)
+            vertical_layout.addSpacing(20)
+            vertical_layout.addLayout(buttons_layout)
+            vertical_layout.addStretch()
+        else:
+            vertical_layout.addLayout(label_layout)
+            vertical_layout.addLayout(buttons_layout)
+
+        general_layout = QHBoxLayout()
+        if not MAC:
+            general_layout.addStretch()
+            general_layout.addLayout(layout)
+            general_layout.addSpacing(1)
+            general_layout.addLayout(vertical_layout)
+            general_layout.addStretch()
+        else:
+            general_layout.addLayout(layout)
+            general_layout.addLayout(vertical_layout)
+
+        self.setLayout(general_layout)
+
+        self.launch_tour_button.clicked.connect(self._start_tour)
+        self.dismiss_button.clicked.connect(self.close)
+        self.setStyleSheet(f"background-color:{dialog_tour_color}")
+        self.setContentsMargins(18, 40, 18, 40)
+        if not MAC:
+            self.setFixedSize(640, 280)
+
+    def _start_tour(self):
+        self.close()
+        self.tour_function()
+
+
 # ----------------------------------------------------------------------------
 # Used for testing the functionality
 
