@@ -31,22 +31,24 @@ from qtpy.QtWidgets import (QHBoxLayout, QLabel, QMenu, QMessageBox,
                             QToolButton, QVBoxLayout, QWidget)
 
 # Local imports
-from spyder.config.base import (_, get_image_path, get_module_source_path,
+from spyder.config.base import (_, get_module_source_path,
                                 running_under_pytest)
 from spyder.config.manager import CONF
-from spyder.utils import icon_manager as ima
+from spyder.utils.icon_manager import ima
 from spyder.utils import sourcecode
+from spyder.utils.image_path_manager import get_image_path
 from spyder.utils.encoding import get_coding
 from spyder.utils.environ import RemoteEnvDialog
+from spyder.utils.palette import QStylePalette
 from spyder.utils.programs import get_temp_dir
 from spyder.utils.qthelpers import (add_actions, create_action,
                                     create_toolbutton, DialogManager,
                                     MENU_SEPARATOR)
 from spyder.py3compat import to_text_string
 from spyder.plugins.ipythonconsole.widgets import ShellWidget
+from spyder.utils.stylesheet import PANES_TABBAR_STYLESHEET
+from spyder.widgets.collectionseditor import CollectionsEditor
 from spyder.widgets.mixins import SaveHistoryMixin
-from spyder.plugins.variableexplorer.widgets.collectionseditor import (
-        CollectionsEditor)
 
 
 #-----------------------------------------------------------------------------
@@ -96,6 +98,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                  show_elapsed_time=False,
                  reset_warning=True,
                  ask_before_restart=True,
+                 ask_before_closing=False,
                  css_path=None):
         super(ClientWidget, self).__init__(plugin)
         SaveHistoryMixin.__init__(self, history_filename)
@@ -112,6 +115,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.show_elapsed_time = show_elapsed_time
         self.reset_warning = reset_warning
         self.ask_before_restart = ask_before_restart
+        self.ask_before_closing = ask_before_closing
 
         # --- Other attrs
         self.options_button = options_button
@@ -123,6 +127,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.stderr_dir = None
         self.is_error_shown = False
         self.restart_thread = None
+        self.give_focus = True
 
         if css_path is None:
             self.css_path = CSS_PATH
@@ -265,12 +270,11 @@ class ClientWidget(QWidget, SaveHistoryMixin):
 
     def configure_shellwidget(self, give_focus=True):
         """Configure shellwidget after kernel is connected."""
+        self.give_focus = give_focus
+
         # Make sure the kernel sends the comm config over
         self.shellwidget.call_kernel()._send_comm_config()
 
-        if give_focus:
-            self.get_control().setFocus()
-
         # Set exit callback
         self.shellwidget.set_exit_callback()
 
@@ -314,6 +318,12 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         # To apply style
         self.set_color_scheme(self.shellwidget.syntax_style, reset=False)
 
+    def add_to_history(self, command):
+        """Add command to history"""
+        if self.shellwidget.is_debugging():
+            return
+        return super(ClientWidget, self).add_to_history(command)
+
     def _before_prompt_is_ready(self):
         """Configure shellwidget before kernel is connected."""
         self._show_loading_page()
@@ -339,6 +349,13 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.shellwidget.sig_remote_execute.disconnect(
             self._when_prompt_is_ready)
 
+        # It's necessary to do this at this point to avoid giving
+        # focus to _control at startup.
+        self._connect_control_signals()
+
+        if self.give_focus:
+            self.shellwidget._control.setFocus()
+
     def enable_stop_button(self):
         self.stop_button.setEnabled(True)
 
@@ -347,7 +364,12 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         # re-running files on dedicated consoles.
         # See spyder-ide/spyder#5958.
         if not self.shellwidget._executing:
-            self.stop_button.setDisabled(True)
+            # This avoids disabling the button while debugging
+            # see spyder-ide/spyder#13283
+            if not self.shellwidget.is_waiting_pdb_input():
+                self.stop_button.setDisabled(True)
+            else:
+                self.stop_button.setEnabled(True)
 
     @Slot()
     def stop_button_click_handler(self):
@@ -357,7 +379,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         if not self.shellwidget.is_waiting_pdb_input():
             self.interrupt_kernel()
         else:
-            self.shellwidget.pdb_execute('exit', hidden=True)
+            self.shellwidget.pdb_execute_command('exit')
 
     def show_kernel_error(self, error):
         """Show kernel initialization errors in infowidget."""
@@ -462,6 +484,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
             self.stop_button.clicked.connect(self.stop_button_click_handler)
         if self.stop_button is not None:
             buttons.append(self.stop_button)
+        self.stop_button.setStyleSheet(str(PANES_TABBAR_STYLESHEET))
 
         # Reset namespace button
         if self.reset_button is None:
@@ -473,7 +496,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                                     triggered=self.reset_namespace)
         if self.reset_button is not None:
             buttons.append(self.reset_button)
-
+        self.reset_button.setStyleSheet(str(PANES_TABBAR_STYLESHEET))
         if self.options_button is None:
             options = self.get_options_menu()
             if options:
@@ -602,6 +625,11 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                 sw.kernel_manager.autorestart = False
 
                 # Create and run restarting thread
+                if (self.restart_thread is not None
+                        and self.restart_thread.isRunning()):
+                    self.restart_thread.finished.disconnect()
+                    self.restart_thread.terminate()
+                    self.restart_thread.wait()
                 self.restart_thread = QThread()
                 self.restart_thread.run = self._restart_thread_main
                 self.restart_thread.error = None
@@ -640,7 +668,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         else:
             # Reset Pdb state and reopen comm
             sw._pdb_in_loop = False
-            sw.spyder_kernel_comm.close()
+            sw.spyder_kernel_comm.remove()
             sw.spyder_kernel_comm.open_comm(sw.kernel_client)
 
             # Start autorestart mechanism
@@ -736,9 +764,9 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         else:
             fmt = "%H:%M:%S"
         if end:
-            color = "#AAAAAA"
+            color = QStylePalette.COLOR_TEXT_3
         else:
-            color = "#AA6655"
+            color = QStylePalette.COLOR_ACCENT_4
         text = "<span style=\'color: %s\'><b>%s" \
                "</b></span>" % (color,
                                 time.strftime(fmt, time.gmtime(elapsed_time)))
@@ -767,7 +795,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     def _create_loading_page(self):
         """Create html page to show while the kernel is starting"""
         loading_template = Template(LOADING)
-        loading_img = get_image_path('loading_sprites.png')
+        loading_img = get_image_path('loading_sprites')
         if os.name == 'nt':
             loading_img = loading_img.replace('\\', '/')
         message = _("Connecting to kernel...")
@@ -856,3 +884,16 @@ class ClientWidget(QWidget, SaveHistoryMixin):
             return True
         else:
             return False
+
+    def _connect_control_signals(self):
+        """Connect signals of control widgets."""
+        control = self.shellwidget._control
+        page_control = self.shellwidget._page_control
+
+        control.focus_changed.connect(
+            lambda: self.plugin.focus_changed.emit())
+        page_control.focus_changed.connect(
+            lambda: self.plugin.focus_changed.emit())
+        control.visibility_changed.connect(self.plugin.refresh_plugin)
+        page_control.visibility_changed.connect(self.plugin.refresh_plugin)
+        page_control.show_find_widget.connect(self.plugin.find_widget.show)
